@@ -1,3 +1,4 @@
+import enum
 import os
 import sys
 import json
@@ -21,7 +22,6 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
-        print(raw_json)
         if self.command == "show running-config":
             first = True
             for line in raw_json.split('\n'):
@@ -37,24 +37,25 @@ class Network3Medusa():
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
             json_dict = json.loads(raw_json)
-            print(json_dict)
-            # first = True
-            # it = iter(json_dict)
-            # size = 6000
-            # for i in range(0, len(json_dict), size):
-            #     if first:
-            #         first = False
-            #         payload = yield {k:json_dict[k] for k in islice(it, size)}
-            #         self.add_file_to_hedera(payload)
-            #     else:
-            #         payload = yield {k:json_dict[k] for k in islice(it, size)}
-            #         self.append_file_to_hedera(payload)
-            # query = FileInfoQuery().setFileId(self.fileId)
-            # info = query.execute(self.client)
-            # print("File size according to `FileInfoQuery`: ", info.size)            
-            # if WEBEX_ROOM:
-            #     self.send_webex_notification()
-      
+            first = True
+            for item in self.chunks(json_dict, 3):
+                print(item)
+                if first:
+                    first = False
+                    self.add_file_to_hedera(item)
+                else:
+                    self.append_file_to_hedera(item)
+            query = FileInfoQuery().setFileId(self.fileId)
+            info = query.execute(self.client)
+            print("File size according to `FileInfoQuery`: ", info.size)            
+            if WEBEX_ROOM:
+                self.send_webex_notification()
+
+    def chunks(self, data, SIZE=6000):
+        it = iter(data)
+        for i in range(0, len(data), SIZE):
+            yield {k:data[k] for k in islice(it, SIZE)}
+
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
